@@ -8,6 +8,8 @@ no warnings 'uninitialized';
 use Yote::IO::FixedStore;
 use Yote::IO::StoreManager;
 
+use Devel::FindRef;
+use WeakRef;
 use File::Path qw(make_path);
 use JSON;
 
@@ -158,11 +160,10 @@ sub get_id {
 sub list_insert {
   my( $self, $list_id, $val, $idx ) = @_;
   my $obj = $self->fetch( $list_id ) || [ $list_id, 'ARRAY', [] ];
-
   if ( ref( $obj->[DATA] ) ne 'ARRAY' ) {
     $obj->[DATA]{ $idx } = $val;
   } else {
-    if ( defined $idx && $idx < @{$obj->[DATA]} ) {
+    if ( defined( $idx ) && $idx < @{$obj->[DATA]} ) {
       splice @{$obj->[DATA]}, $idx, 0, $val;
     } else {
       push @{$obj->[DATA]}, $val;
@@ -373,7 +374,6 @@ sub _recycle_objects {
     $is_first = 1;
   }
   unless( $keep_store ) {
-    # todo ... pick randomized name as this is temporary
     $keep_store = new Yote::IO::FixedStore( "I", $self->{args}{store} . '/RECYCLE' ),
       $keep_store->ensure_entry_count( $self->{OBJ_INDEX}->entries );
 
@@ -383,6 +383,7 @@ sub _recycle_objects {
       $keep_store->put_record( $_, [ 1 ] );
     }
   }
+
   my( $has ) = @{ $keep_store->get_record( $keep_id ) };
   return if $has;
 
@@ -400,10 +401,10 @@ sub _recycle_objects {
   if ( $is_first ) {
     # the purge begins here
     my $count = 0;
-    my $cands = $keep_store->entries;
+    my $cands = $self->{OBJ_INDEX}->entries;
 
     my( %weak_only_check, @weaks, %weaks );
-    for ( 1..$cands) {
+    for ( 1..$cands) { #iterate each id in the entire object store
       my( $rec ) = @{ $keep_store->get_record( $_ ) };
       my $wf = $Yote::ObjProvider::WEAK_REFS->{$_};
 
@@ -411,44 +412,54 @@ sub _recycle_objects {
       # weak references, then it can be removed";
       if ( ! $rec ) {
         if( $wf ) {
-          push @weaks, [ $_, $wf ];
-          $weak_only_check{ $_ } = 1;
+            push @weaks, [ $_, $wf ];
         }
-        else {
+        else { #this case is something in the db that is not connected to the root and not loaded anywhere
           ++$count;
           $self->{OBJ_INDEX}->delete( $_, 1 );
         }
       }
     }
-    for my $wf (@weaks) {
-      my( $id, $obj ) = @$wf;
-      if ( ref( $obj ) eq 'ARRAY' ) {
-        for ( grep { $weak_only_check{$_} }
-              map { Yote::ObjProvider::xform_in($_) } @$obj ) {
-          $weak_only_check{ $_ }++;
+    # check things attached to the weak refs.
+    for my $wf (@weaks) { 
+        my( $id, $obj ) = @$wf;
+        if ( ref( $obj ) eq 'ARRAY' ) { 
+            for ( map { Yote::ObjProvider::xform_in($_) } @$obj ) {
+                $weak_only_check{ $_ }++;
+            }
+        } elsif ( ref( $obj ) eq 'HASH' ) {
+            for ( map { Yote::ObjProvider::xform_in($_) } values %$obj) {
+                $weak_only_check{ $_ }++;
+            }
+        } else {
+            for ( values %{ $obj->{DATA} } ) {
+                $weak_only_check{ $_ }++;
+            }
         }
-      } elsif ( ref( $obj ) eq 'HASH' ) {
-        for ( grep { $weak_only_check{$_} } map { Yote::ObjProvider::xform_in($_) } values %$obj) {
-          $weak_only_check{ $_ }++;
-        }
-      } else {
-        for ( grep { $weak_only_check{$_} } map { Yote::ObjProvider::xform_in($_) } values %{$obj->{DATA}} ) {
-          $weak_only_check{ $_ }++;
-        }
-      }
     } #each weak
-    @weaks = ();
 
     # can delete things with only references to the WEAK and DIRTY caches.
     my( @to_delete );
-    for( keys %weak_only_check ) {
-      if( $weak_only_check{$_} >= (refcount($Yote::ObjProvider::WEAK_REFS->{$_}) - ( $Yote::ObjProvider::DIRTY->{$_} ? 1 : 0 ) )) {
-          push @to_delete, $_;
-          ++$count;
-      }
+    for my $weak ( @weaks ) {
+        my( $id, $obj ) = @$weak;
+        unless( $obj ) {
+            push @to_delete, $id;
+            ++$count;
+        } else {
+            my $extra_refs = 2;
+            # hash and array have an additional reference in the tie
+            if( ref( $obj ) =~ /^(ARRAY|HASH)$/ ) {
+                $extra_refs++;
+            }
+            if( ($extra_refs+$weak_only_check{$id}) >= refcount($obj) ) {
+                push @to_delete, $id;
+                ++$count;
+            }
+        }
     }
     for( @to_delete ) {
         $self->{OBJ_INDEX}->delete( $_, 1 );
+        delete $Yote::ObjProvider::WEAK_REFS->{$_};
     }
 
     # remove recycle datastore
